@@ -15,7 +15,7 @@
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
 #include <ivrconfig.h>
-#include <bayonne.h>
+#include <server.h>
 #include <cc++/audio.h>
 
 #ifdef	HAVE_LINUX_TELEPHONY_H
