@@ -94,6 +94,7 @@ bool PhonedevTrunk::idleHandler(TrunkEvent *event)
 		handler = &PhonedevTrunk::busyHandler;
 		return true;
 	case TRUNK_TIMER_EXPIRED:
+		flags.ready = true;
 		req = group->getRequest();
 		if(req)
 		{
@@ -104,6 +105,7 @@ bool PhonedevTrunk::idleHandler(TrunkEvent *event)
 				flags.trunk = TRUNK_MODE_OUTGOING;
 				setList(argv);
 				endTimer();
+				flags.ready = false;
 				handler = &PhonedevTrunk::seizeHandler;
 				group->incOutgoing();
 				delete req;
@@ -141,6 +143,7 @@ bool PhonedevTrunk::idleHandler(TrunkEvent *event)
 				if(data && value)
 					setConstant(data, value);
 			}
+			flags.ready = false;
 			endTimer();		
 			if(flags.trunk == TRUNK_MODE_OUTGOING)
 			{
@@ -161,6 +164,7 @@ bool PhonedevTrunk::idleHandler(TrunkEvent *event)
 		rings = 1;
 		flags.trunk = TRUNK_MODE_INCOMING;
 		group->incIncoming();
+		flags.ready = false;
 		endTimer();
 		handler = &PhonedevTrunk::ringHandler;
 		return true;
