@@ -34,8 +34,8 @@ PhonedevRecord::~PhonedevRecord()
 
 	Terminate();
 	sprintf(buffer, "%ld", getPosition());
-	trunk->setSymbol("recorded", buffer);
-	trim = tobytes(getEncoding(), atoi(trunk->getSymbol("trim")));
+	trunk->setSymbol(SYM_RECORDED, buffer);
+	trim = tobytes(getEncoding(), atoi(trunk->getSymbol(SYM_TRIM)));
 	stat(data->record.name, &ino);
 	truncate(data->record.name, ino.st_size - trim);
 	chown(data->record.name, keyserver.getUid(), keyserver.getGid());
@@ -60,11 +60,11 @@ void PhonedevRecord::Initial(void)
 	info.format = AUDIO_FORMAT_RAW;
 	info.encoding = MULAW_AUDIO_ENCODING;
 	info.order = 0;
-	info.annotation = trunk->getSymbol("annotation");
+	info.annotation = trunk->getSymbol(SYM_ANNOTATION);
 	info.rate = 8000;
 	
 	if(!ext)
-		ext = trunk->getSymbol("extension");
+		ext = trunk->getSymbol(SYM_EXTENSION);
 
 	if(!stricmp(ext, ".al"))
 		info.encoding = ALAW_AUDIO_ENCODING;
@@ -210,7 +210,7 @@ bool PhonedevTrunk::recordHandler(TrunkEvent *event)
 		handler = &PhonedevTrunk::stepHandler;
 		return true;
 	case TRUNK_SERVICE_FAILURE:
-		setSymbol("error", "record-failed");
+		setSymbol(SYM_ERROR, "record-failed");
 		TrunkSignal(TRUNK_SIGNAL_ERROR);
 		handler = &PhonedevTrunk::stepHandler;
 		return true;
