@@ -31,7 +31,7 @@ bool PhonedevTrunk::sleepHandler(TrunkEvent *event)
 		tgi.pid = 0;
 		endTimer();
 		sprintf(buffer, "exit-%d", event->parm.status);
-		setSymbol("error", buffer);
+		setSymbol(SYM_ERROR, buffer);
 		if(event->parm.status)
 			TrunkSignal(TRUNK_SIGNAL_ERROR);
 		else
@@ -91,7 +91,7 @@ bool PhonedevTrunk::sleepHandler(TrunkEvent *event)
 		}
 		else
 		{
-			setSymbol("error", event->parm.lookup.data);
+			setSymbol(SYM_ERROR, event->parm.lookup.data);
 			TrunkSignal(TRUNK_SIGNAL_ERROR);
 		}
 		handler = &PhonedevTrunk::stepHandler;
