@@ -214,14 +214,19 @@ private:
 	PikaTrunk **ports;
 	trunkdsp_t *dsps;
 
+	bool keyflag;
 	unsigned card_count;
 	unsigned port_count;
 	unsigned dsp_count;
 
+	void Run(void) {return;};
+	void OnSignal(int signo) {return;};
+
 public:
 	PikaDriver();
 	~PikaDriver();
 
+	void callback(void);
 	int Start(void);
 	void Stop(void);
 
