@@ -66,6 +66,7 @@ bool PikaTrunk::idleHandler(TrunkEvent *event)
 		endTimer();
 
 		digits = 0;
+		flags.ready = false;
 		flags.offhook = false;
 		PK_TRUNK_OnHook(hTrk);
 
@@ -98,11 +99,13 @@ bool PikaTrunk::idleHandler(TrunkEvent *event)
 		return true;
 	case TRUNK_MAKE_BUSY:
 		endTimer();
+		flags.ready = false;
 		handler = &PikaTrunk::busyHandler;
 		return true;
 	case TRUNK_MAKE_IDLE:
 		return true;
 	case TRUNK_TIMER_EXPIRED:
+		flags.ready = true;
 		req = group->getRequest();
 		if(req)
 		{
@@ -113,6 +116,7 @@ bool PikaTrunk::idleHandler(TrunkEvent *event)
 				flags.trunk = TRUNK_MODE_OUTGOING;
 				setList(argv);
 				endTimer();
+				flags.ready = false;
 				handler = &PikaTrunk::stepHandler;
 				group->incOutgoing();
 				delete req;
@@ -144,6 +148,7 @@ bool PikaTrunk::idleHandler(TrunkEvent *event)
 			}		
 		
 		  endTimer();
+		  flags.ready = false;
 		  // Looks like following call needed to start script executing?
 		  // Maybe should be stepHandler?
 		  handler = &PikaTrunk::stepHandler;
@@ -182,6 +187,7 @@ bool PikaTrunk::idleHandler(TrunkEvent *event)
 				if(data && value)
 					setConstant(data, value);
 			}
+		 	flags.ready = false;
 			endTimer();		
 			handler = &PikaTrunk::stepHandler;
 			group->incIncoming();
@@ -193,6 +199,7 @@ bool PikaTrunk::idleHandler(TrunkEvent *event)
 	case TRUNK_RINGING_ON:
 		rings = 1;
 		group->incIncoming();
+		flags.ready = false;
 		endTimer();
 		handler = &PikaTrunk::ringHandler;
 		return true;
