@@ -66,8 +66,8 @@ PikaRecord::~PikaRecord()
 	clrAudio();
 	Terminate();
 	sprintf(buffer, "%ld", getPosition());
-	trunk->setSymbol("recorded", buffer);
-	trim = tobytes(getEncoding(), atoi(trunk->getSymbol("trim")));
+	trunk->setSymbol(SYM_RECORDED, buffer);
+	trim = tobytes(getEncoding(), atoi(trunk->getSymbol(SYM_TRIM)));
 	Close();
 
 	stat(data->record.name, &ino);
@@ -99,18 +99,18 @@ void PikaRecord::Initial(void)
 	unsigned codec, speed, rate, len, count = 0;
 	char buffer[32];
 	char *ext = strrchr(data->record.name, '.');
-	char *fmt = trunk->getSymbol("format");
+	char *fmt = trunk->getSymbol(SYM_FORMAT);
 	audioinfo_t recinfo;
 
 	trunk->getName(buffer);
 	recinfo.format = AUDIO_FORMAT_RAW;
 	recinfo.encoding = MULAW_AUDIO_ENCODING;
 	recinfo.order = 0;
-	recinfo.annotation = trunk->getSymbol("annotation");
+	recinfo.annotation = trunk->getSymbol(SYM_ANNOTATION);
 	recinfo.rate = 8000;
 
 	if(!ext)
-		ext = trunk->getSymbol("extension");
+		ext = trunk->getSymbol(SYM_EXTENSION);
 
 	if(!fmt)
 		fmt = "raw";
@@ -291,7 +291,7 @@ bool PikaTrunk::recordHandler(TrunkEvent *event)
 		handler = &PikaTrunk::stepHandler;
 		return true;
 	case TRUNK_SERVICE_FAILURE:
-		setSymbol("error", "play-failed");
+		setSymbol(SYM_ERROR, "play-failed");
 		TrunkSignal(TRUNK_SIGNAL_ERROR);
 		handler = &PikaTrunk::stepHandler;
 		return true;
@@ -314,7 +314,13 @@ bool PikaTrunk::recordHandler(TrunkEvent *event)
 		}
 	case TRUNK_OFF_HOOK:
 		endTimer();
-		getVPResource();
+		if(!getVPResource())
+		{
+			setSymbol(SYM_ERROR, "dsp-unavailable");
+			TrunkSignal(TRUNK_SIGNAL_ERROR);
+			handler = &PikaTrunk::stepHandler;
+			return true;
+		}
 		if(data.record.term)
 			setDTMFDetect(true);
 		else
