@@ -46,18 +46,46 @@
 bool PikaTrunk::ringHandler(TrunkEvent *event)
 {
 	char script[256];
+	char *args[2];
 	int argc = 0;
-	const char *start = NULL;
+	char **start = NULL;
 	const char *data;
 	const char *value;
 	TrunkGroup *grp = NULL;
+	unsigned char msgtype, msgsize, totsize;
+
+	enum
+	{
+		SMT_CALLING_NUMBER_DELIVERY_INFO = 0x04,
+		SMT_MESSAGE_WAITING_INDICATOR = 0x0a,
+		SMT_MESSAGE_DESK_INFO = 0x0b,
+		MMT_CALL_SETUP=0x80,
+		MMT_TEST_CALLING_NUMBER_DELIVERY=0x81,
+		MMT_MESSAGE_WAITING_NOTIFICATION=0x82
+	};
+
+	enum
+	{
+		MPT_TIME = 1,
+		MPT_CALLING_LINE_DIRECTORY_NUMBER,
+		MPT_DIALABLE_DIRECTORY_NUMBER,
+		MPT_REASON_FOR_ABSENCE_OF_DIRECTORY_NUMBER,
+		MPT_REASON_FOR_REDIRECTION,
+		MPT_CALL_QUALIFIER,
+		MPT_NAME,
+		MPT_REASON_FOR_ABSENCE_OF_NAME
+	};	
 
 	switch(event->id)
 	{
+	case TRUNK_DSP_READY:
+		PK_CID_Disable(hDsp);
+		return true;
 	case TRUNK_ENTER_STATE:
 		debug->DebugState(this, "ringing");
 		status[id] = 'r';
-		getCIDResource();
+		if(group->getAnswer() > 1)
+			getCIDResource();
 		return true;
 	case TRUNK_START_SCRIPT:
 		return false;
@@ -68,9 +96,59 @@ bool PikaTrunk::ringHandler(TrunkEvent *event)
 		++rings;
 		endTimer();
 		return true;
+	case TRUNK_CALLER_ID:
+		data = (const char *)event->parm.data;
+		msgtype = data[0];
+		msgsize = totsize = data[1];
+		data += 2;
+		switch(msgtype)
+		{
+		case SMT_CALLING_NUMBER_DELIVERY_INFO:
+			break;
+		case MMT_CALL_SETUP:
+			while(totsize)
+			{
+				msgtype = data[0];
+				msgsize = data[1];
+				if(msgsize > totsize)
+					msgsize = totsize;
+				data += 2;
+				switch(msgtype)
+				{
+				case MPT_REASON_FOR_ABSENCE_OF_DIRECTORY_NUMBER:
+				case MPT_CALLING_LINE_DIRECTORY_NUMBER:
+					memcpy(script, data, msgsize);
+					script[msgsize] = 0;
+					setConstant(SYM_CALLER, script);
+					break;
+				case MPT_REASON_FOR_ABSENCE_OF_NAME:
+				case MPT_NAME: 
+					memcpy(script, data, msgsize);
+					script[msgsize] = 0;
+					setConstant(SYM_NAME, script);
+				}
+				data += msgsize;
+				totsize -= (msgsize + 2);
+			}
+			break;
+		default:
+			slog(SLOG_DEBUG) << "unsupported cid entity" << endl;
+			break;
+		}
+		stopDSP();
+		if(rings < group->getAnswer())
+			return true;
 	case TRUNK_RINGING_OFF:
-		if(rings > 1)
-			stopDSP();
+		if(rings == 1 && flags.dsp == DSP_MODE_CALLERID)
+		{
+			if(PK_CID_Enable(hDsp))
+				slog(SLOG_DEBUG) << pikaivr.getCardName(card) << id << ": callerid activation failed" << endl;
+		} 
+		if(rings == group->getAnswer() && flags.dsp == DSP_MODE_CALLERID)
+		{
+			setTimer(group->getRingTime() * 1000);
+			return true;
+		}
 		if(rings < group->getAnswer())
 		{
 			setTimer(group->getRingTime() * 1000);
@@ -79,9 +157,10 @@ bool PikaTrunk::ringHandler(TrunkEvent *event)
 		sprintf(script, "ring%d", event->parm.ring.digit);
 		if(!grp)
 			grp = group;
-		start = group->getSchedule(script);
-		if(Attach(start))
+		start = getInitial(args);
+		if(Attach(*start))
 		{
+			setList(++start);
 			handler = &PikaTrunk::stepHandler;
 			return true;
 		}
