@@ -108,21 +108,14 @@ bool PikaTrunk::getCIDResource(void)
 	if(!hDsp)
 		return false;
 
-
-	if(PK_MVIP_FullDuplexConnect(hTrk, hDsp))
+	if(PK_MVIP_HalfDuplexConnect(hTrk, hDsp))
 	{
 		slog(SLOG_ERROR) << pikaivr.getCardName(card) << id << ": cannot connect cid resource" << endl;
  		return false;
 	}
-	PK_DSP_SetEventHandler(hDsp, id, (pikacall_t)&PikaTrunk::callback);
-
-	rtn = PK_CID_SetBuffer(hDsp, cidbuf, PK_CID_BUFFER_SIZE);
-	PK_CID_SetTimeOut(hDsp, PK_CID_DEFAULT_TIME_OUT);	
-	if(PK_CID_Enable(hDsp))
-	{
-		slog(SLOG_DEBUG) << pikaivr.getCardName(card) << id << ": cannot activate callerid" << endl;
-		return false;
-	}
+	PK_DSP_SetEventHandler(hDsp, (PK_U32)id, (pikacall_t)&PikaTrunk::callback);
+	PK_CID_SetBuffer(hDsp, cidbuf, PK_CID_BUFFER_SIZE);
+	PK_CID_SetTimeOut(hDsp, group->getCallerid());
 	flags.dsp = DSP_MODE_CALLERID;
 	return true;
 }
@@ -438,6 +431,10 @@ void PikaTrunk::callback(PK_U32 id, PK_U32 pk, PK_U32 p1, PK_U32 p2)
 	case PK_EVENT_TGEN_INVALID_TONE:
 		event.id = TRUNK_TONE_IDLE;
 		break;
+	case PK_EVENT_CID_READY:
+		event.id = TRUNK_DSP_READY;
+		event.parm.dsp = DSP_MODE_CALLERID;
+		break;
 	case PK_EVENT_CID_REPORT:
 		if(p1)
 			return;
