@@ -22,6 +22,15 @@ bool VPBTrunk::busyHandler(TrunkEvent *event)
 	{
 	case TRUNK_ENTER_STATE:
 		debug->DebugState(this, "busy");
+		switch(flags.trunk)
+		{
+		case TRUNK_MODE_OUTGOING:
+			group->decOutgoing();
+			break;
+		case TRUNK_MODE_INCOMING:
+			group->decIncoming();
+		}
+		flags.trunk = TRUNK_MODE_UNAVAILABLE;
 		status[id] = '*';
 		endTimer();
 		if(thread)
