@@ -43,6 +43,7 @@ private:
 
 	void getName(char *buffer);
 	unsigned long getIdleTime(void);
+	unsigned getPickupTimer(void);
 	
 	bool stepHandler(TrunkEvent *event);
 	bool busyHandler(TrunkEvent *event);
@@ -104,13 +105,13 @@ class VPBConfig : public Keydata
 public:
 	VPBConfig();
 
-	int getOffset(void)
+	unsigned getOffset(void)
 		{return strtol(getLast("first"), NULL, 16);};
 
-	int getCards(void)
+	unsigned getCards(void)
 		{return atoi(getLast("cards"));};
 
-	int getHookTimer(void)
+	inline unsigned getHookTimer(void)
 		{return atoi(getLast("hooktime"));};
 
 	size_t getStack(void);
