@@ -36,8 +36,8 @@ bool VPBTrunk::flashoffHandler(TrunkEvent *event)
 		debug->DebugState(this, "flashoff");
 		flags.offhook = true;
 		vpb_sethook_async(handle, VPB_OFFHOOK);
-		if(data.flash.offhook < vpbivr.getHookTimer())
-			data.flash.offhook = vpbivr.getHookTimer();
+		if(data.flash.offhook < getPickupTimer())
+			data.flash.offhook = getPickupTimer();
 		setTimer(data.flash.offhook);
 		return true;
 	}
