@@ -73,7 +73,8 @@ bool VPBTrunk::idleHandler(TrunkEvent *event)
 		endTimer();
 		handler = &VPBTrunk::busyHandler;
 		return true;
-	case TRUNK_TIMER_EXPIRED:
+	case TRUNK_TIMER_EXPIRED:	
+		flags.ready = true;
 		req = group->getRequest();
 		if(req)
 		{
@@ -83,6 +84,7 @@ bool VPBTrunk::idleHandler(TrunkEvent *event)
 			{
 				flags.trunk = TRUNK_MODE_OUTGOING;
 				setList(argv);
+				flags.ready = false;
 				endTimer();
 				handler = &VPBTrunk::seizeHandler;
 				group->incOutgoing();
@@ -121,6 +123,7 @@ bool VPBTrunk::idleHandler(TrunkEvent *event)
 				if(data && value)
 					setConstant(data, value);
 			}
+			flags.ready = false;
 			endTimer();		
 			if(flags.trunk == TRUNK_MODE_OUTGOING)
 			{
@@ -140,6 +143,7 @@ bool VPBTrunk::idleHandler(TrunkEvent *event)
 	case TRUNK_RINGING_ON:
 		rings = 1;
 		flags.trunk = TRUNK_MODE_INCOMING;
+		flags.ready = false;
 		endTimer();
 		group->incIncoming();
 		handler = &VPBTrunk::ringHandler;
