@@ -287,7 +287,7 @@ static bool sayprimary(strstream *s, const char *text)
 	return true;
 }
 
-static bool saylocal(strstream *s, double v, bool or)
+static bool saylocal(strstream *s, double v, bool orflag)
 {
 	char tbuf[33];
 	const char *cu = keylocal.getLast("localcurrency");
