@@ -56,13 +56,22 @@ class Trunk;
 class Service;
 class phTone;
 class TrunkGroup;
+class Module;
+
+typedef enum
+{
+	SELECT_FIRST,
+	SELECT_LAST
+} seltype_t;
 
 typedef enum {
+	MODULE_GENERIC,
 	MODULE_DELIVERY,
 	MODULE_SENDFILE,
 	MODULE_SENDFAX,
 	MODULE_NOTIFY,
-	MODULE_TGI
+	MODULE_TGI,
+	MODULE_ANY
 }	modtype_t;
 
 typedef enum {
@@ -1128,6 +1137,13 @@ public:
 	inline const char *chkRequest(void)
 		{return getLast("requests");};
 
+	/**
+	 * Get a trunk group port selection method.
+	 *
+	 * @return select method.
+	 */
+	seltype_t getSelect(void);
+
 	/**
 	 * Get ready timer for trunk before handling requests when
 	 * idle.
@@ -1248,14 +1264,6 @@ public:
 	inline const char *getToken(void)
 		{return getLast("token");};
 
-	/**
-	 * Search for a specific named trunk group.
-	 *
-	 * @return pointer to TrunkGroup record.
-	 * @param name of trunk group to find.
-	 */
-	TrunkGroup *getGroup(char *name);
-
 	/**
 	 * Load all active trunk group records.
 	 */
@@ -1434,6 +1442,13 @@ public:
 	 * Default scripting environment.
 	 */
 	aaScript();
+
+	/**
+	 * Used to bind "generic" modules to aaScript.
+	 *
+	 * @param Module to bind.
+	 */
+	void addModule(Module *module);
 };
 
 /**
@@ -1520,12 +1535,7 @@ private:
 	bool scrTransfer(void);
 	bool scrSpeak(void);
 	bool scrMap(void);
-	bool scrLookup(void);
-	bool scrUpdate(void);
-	bool scrDeliver(void);
-	bool scrSendfile(void);
-	bool scrNotify(void);
-	bool scrSendfax(void);
+	bool scrModule(void);
 
 protected:
 	static ScriptSymbol globals;
@@ -1553,7 +1563,8 @@ protected:
 		bool timer : 1;
 		bool audio: 1;
 		bool once : 1;
-		unsigned temp : 4;
+		bool ready : 1;
+		unsigned temp : 2;
 		trunkmode_t trunk: 2;
 		dspmode_t dsp: 4;
 	} flags;
@@ -1743,6 +1754,12 @@ public:
 	 */
 	int getDigit(char digit);
 
+	/**
+	 * See if trunk is idle and available.
+	 *
+	 * @return true if ready.
+	 */
+	bool isReady(void);
 };
 
 /**
@@ -2417,6 +2434,7 @@ protected:
 	 */
 	virtual modtype_t getType(void) = 0;
 
+public:
 	/**
 	 * Get the "name" identifer of this module.
 	 *
@@ -2424,7 +2442,6 @@ protected:
 	 */
 	virtual char *getName(void) = 0;
 
-public:
 	/**
 	 * Execute the script request.  Usually this involves creating
 	 * a detached service thread.
@@ -2434,8 +2451,26 @@ public:
 	 */
 	virtual char *Dispatch(Trunk *trunk) = NULL;
 
+	/**
+	 * This is used to determine if a timeout/sleep should occur
+	 * or if script advance is immediate.
+	 *
+	 * @return number of seconds in sleep state.
+	 * @param trunk object to reference.
+	 */
+	virtual unsigned Sleep(Trunk *trunk)
+		{return 0;};
+
+	/**
+	 * Notify for detach.  As each call is detached, this will
+	 * get called.
+	 */
+	virtual void Detach(Trunk *trunk)
+		{return;};
+
 public:
 	friend Module *getModule(modtype_t mod, const char *name = NULL);
+	friend void detachModules(Trunk *trunk);
 };
 
 /**
