@@ -61,12 +61,6 @@ ScriptCommand("/bayonne/script")
 		{"libonce", (scriptmethod_t)&Trunk::scrLibonce, &ScriptCommand::chkHasArgs},
 		{"speak", (scriptmethod_t)&Trunk::scrSpeak, &ScriptCommand::chkHasArgs},
 		{"map", (scriptmethod_t)&Trunk::scrMap, &ScriptCommand::chkHasArgs},
-		{"lookup", (scriptmethod_t)&Trunk::scrLookup, &ScriptCommand::chkHasArgs},
-		{"update", (scriptmethod_t)&Trunk::scrUpdate, &ScriptCommand::chkHasArgs},
-		{"deliver", (scriptmethod_t)&Trunk::scrDeliver, &ScriptCommand::chkHasArgs},
-		{"sendfax", (scriptmethod_t)&Trunk::scrSendfax, &ScriptCommand::chkHasArgs},
-		{"sendfile", (scriptmethod_t)&Trunk::scrSendfile, &ScriptCommand::chkHasArgs},
-		{"notify", (scriptmethod_t)&Trunk::scrNotify, &ScriptCommand::chkHasArgs},
 		{NULL, NULL, NULL}};
 
 	// pre-load some useful compiler "$constants", some of which
@@ -101,9 +95,6 @@ ScriptCommand("/bayonne/script")
 		{"voice", "UsEngM"},
 		{NULL, NULL}};
 
-	SCRKEYWORDS keywords[2];
-	char **keylist = NULL;
-
 	Keydata::Load("~bayonne/script");
 	setValue("node", keyserver.getNode());
 	setValue("version", BAYONNE_VERSION);
@@ -138,23 +129,26 @@ ScriptCommand("/bayonne/script")
 	Trap("cancel");
 
 	Load(interp);
-
-	if(!keylist)
-		return;
-
-//	while(*keylist)
-//	{
-//		keywords[0].keyword = *keylist;
-//		keywords[0].method = (scriptmethod_t)&Trunk::scrSession;
-//		keywords[0].check = &ScriptCommand::chkHasArgs;
-//		keywords[1].keyword = NULL;
-//		keywords[1].method = (scriptmethod_t)NULL;
-//		keywords[1].check = (scriptcheck_t)NULL;
-//		Load(keywords);
-//		++keylist;
-//	}
 }
 
+void aaScript::addModule(Module *module)
+{
+	char *name = module->getName();
+	SCRKEYWORDS keywords[2];
+	
+	if(!name)
+		return;
+
+	keywords[0].keyword = name;
+	keywords[0].method = (scriptmethod_t)&Trunk::scrModule;
+	keywords[0].check = &ScriptCommand::chkHasArgs;
+	keywords[1].keyword = NULL;
+	keywords[1].method = (scriptmethod_t)NULL;
+	keywords[1].check = (scriptcheck_t)NULL;
+	Load(keywords);
+}
+
+	
 functioncall_t aaScript::getFunction(char *name)
 {
 	functions_t *fun = functions[funid(name)];
