@@ -18,6 +18,8 @@
 #include <pwd.h>
 #include <math.h>
 
+#define	LIB_VERSION	"/" VERPATH "/"
+
 KeyLocal::KeyLocal() :
 Keydata("/bayonne/localize")
 {
@@ -129,20 +131,6 @@ void KeyServer::loadGroups(void)
 	}
 }
 
-TrunkGroup *KeyServer::getGroup(char *name)
-{
-	TrunkGroup *grp = TrunkGroup::first;
-
-	while(grp)
-	{
-		if(!stricmp(name, grp->getName()))
-			break;
-		grp = grp->next;
-	}
-	
-	return grp;
-}
-
 KeyThreads::KeyThreads() :
 Keydata("/bayonne/threads")
 {
@@ -205,8 +193,6 @@ Keydata("/bayonne/database")
 	Load(defkeys);
 }
 
-
-
 InetAddress KeyNetwork::getAddress(void)
 {
 	char buffer[65];
@@ -765,6 +751,7 @@ Keydata("/bayonne/trunks"), CallStat()
 		{"callerid", "1500"},
 		{"pickup", "500"},
 		{"requests", "hangup"},
+		{"select", "last"},
 		{"ready", "1000"},
 		{NULL, NULL}};
 
@@ -815,6 +802,16 @@ Keydata("/bayonne/trunks"), CallStat()
 		first = this;
 }	
 
+seltype_t TrunkGroup::getSelect(void)
+{
+	const char *cp = getLast("select");
+
+	if(!stricmp(cp, "last"))
+		return SELECT_LAST;
+
+	return SELECT_FIRST;
+}
+
 Request *TrunkGroup::getRequest(void)
 {
 	Request *req = NULL;
