@@ -105,8 +105,8 @@ Keydata(conf)
 		Load(lib);
 
 	slog(SLOG_DEBUG) << "loaded lib" << endl;
-	if(isDir("/etc/bayonne.d"))
-		if(canAccess("/etc/bayonne.d"))
+	if(isDir(ETC_PREFIX "bayonne.d"))
+		if(canAccess(ETC_PREFIX "bayonne.d"))
 			scanDir(conf, lib);
 
 	strcpy(keypath, conf);
@@ -125,7 +125,7 @@ void Translator::scanDir(const char *lang, const char *lib)
 {
 	char buffer[65];
 	char *name, *ext;
-	Dir dir("/etc/bayonne.d");
+	Dir dir(ETC_PREFIX "bayonne.d");
 	if(*lang == '/')
 		lang = strrchr(lang, '/');
 
@@ -263,13 +263,24 @@ Module::Module()
 	first = this;
 }
 
+void detachModules(Trunk *trunk)
+{
+	Module *mod = Module::first;
+
+	while(mod)
+	{
+		mod->Detach(trunk);
+		mod = mod->next;
+	}
+}
+
 Module *getModule(modtype_t mtype, const char *name)
 {
 	Module *mod = Module::first;
 
 	while(mod)
 	{
-		if(mod->getType() == mtype)
+		if(mod->getType() == mtype || mtype == MODULE_ANY)
 		{
 			if(!name)
 				return mod;
@@ -284,3 +295,4 @@ Module *getModule(modtype_t mtype, const char *name)
 
 Debug *debug = NULL;
 Driver *driver = NULL;
+
