@@ -48,9 +48,9 @@ void Scheduler::Initial(void)
 	if(sched.is_open())
 		sched.close();
 
-	sched.open("/etc/bayonne.sched");
+	sched.open(ETC_PREFIX "bayonne.sched");
 	if(!sched.is_open())
-		slog(SLOG_WARNING) << "/etc/bayonne.sched: cannot access" << endl;
+		slog(SLOG_WARNING) << ETC_PREFIX "bayonne.sched: cannot access" << endl;
 	else
 	{
 		slog(SLOG_NOTICE) << "scheduler: started" << endl;
@@ -75,6 +75,7 @@ void Scheduler::Run(void)
 	Update();
 	for(;;)
 	{
+		slog(SLOG_DEBUG) << "scheduler starting..." << endl;
 		Sleep(60000);
 		Session::Clean();
 		time(&now);
@@ -219,7 +220,7 @@ int Scheduler::Load(void)
 		p = strtok_r(name, ",;", &sp);	
 		while(p)
 		{
-			group = keyserver.getGroup(p);
+			group = getGroup(p);
 			if(!group) 
 			{ 
 				slog( SLOG_WARNING ) << "scheduler::unknown group '" << p << "' refereced in schedule" << endl;
