@@ -16,6 +16,39 @@
 
 #include "server.h"
 
+bool Trunk::scrModule(void)
+{
+	scriptline_t *line = getScript();
+	Module *module = getModule(MODULE_ANY, line->cmd);
+	char *err;
+	unsigned delay;
+
+	if(!module)
+	{
+		Error("module-not-found");
+		return true;
+	}
+
+	err = module->Dispatch(this);
+	if(err)
+	{
+		Error(err);
+		return true;
+	}
+
+	delay = module->Sleep(this);
+	if(!delay)
+	{
+		Advance();
+		return true;
+	}
+	data.sleep.wakeup = delay * 1000;
+	data.sleep.rings = 0;
+	data.sleep.loops = 1;
+	TrunkStep(TRUNK_STEP_SLEEP);
+	return false;
+}
+
 bool Trunk::scrRecord(void)
 {
 	data.record.name = getValue("");	
@@ -337,88 +370,6 @@ bool Trunk::scrPause(void)
 	return false;
 }
 
-bool Trunk::scrDeliver(void)
-{
-	Module *mod = getModule(MODULE_DELIVERY);
-	char *err;
-
-	if(!getOnce())
-	{
-		Advance();
-		return true;
-	}
-	
-	if(!mod)
-	{
-		Error("no-delivery-protocol");
-		return true;
-	}
-
-	err = mod->Dispatch(this);
-	if(err)
-		Error(err);
-	else
-		Advance();
-	return true;
-}
-
-bool Trunk::scrSendfile(void)
-{
-	Module *mod = getModule(MODULE_SENDFILE);
-	char *err;
-
-	if(!mod)
-	{
-		Error("no-sendfile-protocol");
-		return true;
-	}
-
-	err = mod->Dispatch(this);
-	if(err)
-		Error(err);
-	else
-		Advance();
-	return true;
-}
-
-bool Trunk::scrSendfax(void)
-{
-	Module *mod = getModule(MODULE_SENDFAX);
-	char *err;
-
-	if(!mod)
-	{
-		Error("no-sendfax-protocol");
-		return true;
-	}
-	
-	err = mod->Dispatch(this);
-	if(err)
-		Error(err);
-	else
-		Advance();
-	return true;
-}
-
-bool Trunk::scrNotify(void)
-{
-	Module *mod = getModule(MODULE_NOTIFY, getValue("*"));
-	char *err;
-
-	if(!mod)
-	{
-		Error("no-notify-module");
-		return true;
-	}
-
-	err = mod->Dispatch(this);
-	if(err)
-		Error(err);
-	else
-		Advance();
-	return true;
-}	
-
 bool Trunk::scrLibonce(void)
 {
 	if(getOnce())
@@ -529,73 +480,6 @@ bool Trunk::scrLibexec(void)
 	return false;
 }
 
-bool Trunk::scrLookup(void)
-{
-	char buffer[256];
-	strstream str(buffer, sizeof(buffer));
-	unsigned adapter = atoi(getValue("0"));
-	char *cp;
-	char *opt;
-
-	if(!adapter)
-		++tgi.seq;
-		
-	buffer[0] = 0;
-		
-	str << "L" << id << '\t' << tgi.seq << '\t' << getValue("default");
-	while(NULL != (opt = getOption(NULL)))
-	{
-		cp = getContent(opt);
-		str << '\t' << opt << '=' << cp;
-	}
-	str << ends;
-	buffer[255] = 0;
-
-	if(!network.Query(adapter, buffer, strlen(buffer) + 1))
-	{
-		Error("lookup-failed");
-		return true;
-	}
-	data.sleep.wakeup = keynetwork.getDatabaseDelay() * 1000;
-	data.sleep.rings = 0;
-	data.sleep.loops = 1;
-	TrunkStep(TRUNK_STEP_SLEEP);
-	return false;
-}
-
-bool Trunk::scrUpdate(void)
-{
-	char buffer[256];
-	strstream str(buffer, sizeof(buffer));
-	unsigned adapter = atoi(getValue("0"));
-	char *opt, *cp;
-
-	if(!adapter)
-		++tgi.seq;
-
-	buffer[0] = 0;
-
-	str << "U" << id << '\t' << tgi.seq << '\t' << getValue("default");
-	while(NULL != (opt = getOption(NULL)))
-	{
-		cp = getContent(opt);
-		str << '\t' << opt << opt << '=' << cp;
-	}
-	str << ends;
-	buffer[255] = 0;
-
-	if(!network.Query(adapter, buffer, strlen(buffer) + 1))
-	{
-		Error("updated-failed");
-		return true;
-	}
-	data.sleep.wakeup = keynetwork.getDatabaseDelay() * 1000;
-	data.sleep.rings = 0;
-	data.sleep.loops = 1;
-	TrunkStep(TRUNK_STEP_SLEEP);
-	return false;
-}
-
 bool Trunk::scrTone(void)
 {
 	phTone *tone = getphTone(getValue(""));
