@@ -302,7 +302,7 @@ static void initial(int argc, char **argv)
 			plugins.setValue("debug", "gui");
 			break;			
 		case 'V':
-			cout << LIB_VERSION << endl;
+			cout << VERPATH << endl;
 			exit(0);
 		case 'T':
 			daemon = false;
@@ -492,11 +492,11 @@ static void initial(int argc, char **argv)
 	}
 
 	keyserver.loadGroups();
-	if(canAccess("/etc/bayonne.clid"))
-		new Map("/etc/bayonne.clid", "clid");
+	if(canAccess(ETC_PREFIX "bayonne.clid"))
+		new Map(ETC_PREFIX "bayonne.clid", "clid");
 
-	if(canAccess("/etc/bayonne.dnis"))
-		new Map("/etc/bayonne.dnis", "dnis");
+	if(canAccess(ETC_PREFIX "bayonne.dnis"))
+		new Map(ETC_PREFIX "bayonne.dnis", "dnis");
 
 	plugins.loadMaps();
 
