@@ -104,10 +104,11 @@ public:
 #define	SYM_VOLUME	"volume"
 #define	SYM_FORMAT	"format"
 #define	SYM_ERROR	"error"
-#define	SYM_CALLERTYPE	"callertype"
-#define	SYM_CALLERNAME	"callername"
-#define	SYM_CALLER	"caller"
+#define	SYM_CALLER	"clid"
+#define	SYM_DIALED	"dnid"
+#define	SYM_NAME	"name"
 #define	SYM_RINGID	"ringid"
+#define SYM_INFODIGITS	"infodigits"
 
 extern Network network;
 extern Scheduler scheduler;
