@@ -77,7 +77,7 @@ void Session::Clean(void)
 }
 
 Service::Service(Trunk *trk, int pri) :
-Semaphore(), Thread((Semaphore *)this, pri)
+Semaphore(), Thread((Semaphore *)this, pri, keythreads.getStack())
 {
 	trunk = trk;
 	stopped = false;
