@@ -36,6 +36,7 @@ ScriptInterp((aaScript *)driver, keymemory.getSymbolSize(), keymemory.getPageSiz
 	flags.trunk = TRUNK_MODE_INACTIVE;
 	flags.dsp = DSP_MODE_INACTIVE;
 	flags.script = false;
+	flags.ready = false;
 	id = port;
 	rings = 0;
 	start = idle = 0;
@@ -85,6 +86,14 @@ unsigned long Trunk::getMask(void)
 	return ScriptInterp::getMask();
 }
 
+bool Trunk::isReady(void)
+{
+	if(flags.trunk != TRUNK_MODE_INACTIVE)
+		return false;
+
+	return flags.ready;
+}
+
 void Trunk::setDTMFDetect(void)
 {
 	if(isActive())
@@ -351,6 +360,7 @@ void Trunk::Detach(void)
 		manager->postDetach();
 	else
 		ScriptInterp::Detach();
+	detachModules(this);
 	ScriptSymbol::Purge();
 	start = 0;
 	flags.script = false;
